/***************************************************************************
 * aifffffs.h: AIFF from FLAC file system.
 * Copyright (C) 2011 Michael C McTernan,
 *    Michael.McTernan.2001@cs.bris.ac.uk
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 ***************************************************************************/

#ifndef AIFFFFFS_H
#define AIFFFFFS_H

/**************************************************************************
 * Includes
 **************************************************************************/

#include <string.h>
#include <alloca.h>
#include <stdint.h>
#include <stdbool.h>

/**************************************************************************
 * Macros
 **************************************************************************/

#define M_UnTranslatePath(pATH)                                         \
({                                                                      \
    const char *_path = pATH;                                           \
    size_t      _pathLen = strlen(_path);                               \
    char *const _p = alloca(_pathLen + aifffffs_rootLen);               \
                                                                        \
    strcpy(_p, aifffffs_root);                                          \
    strcpy(&_p[aifffffs_rootLen], _path);                               \
                                                                        \
    /* Check if it ends with aiff */                                    \
    if(isAiffFilename(_path))                                           \
    {                                                                   \
        strcpy(&_p[_pathLen + aifffffs_rootLen - 4], "flac");           \
    }                                                                   \
    _p;                                                                 \
})

/**************************************************************************
 * Types
 **************************************************************************/

extern char    *aifffffs_root;
extern uint32_t aifffffs_rootLen;
extern bool     aifffffs_noMd5;

/**************************************************************************
 * Prototypes
 **************************************************************************/

/** Check if the passed path ends with .aiff.
 */
static inline bool isAiffFilename(const char *path)
{
    size_t pathLen = strlen(path);

    return pathLen > 5 && strcmp(".aiff", &path[pathLen - 5]) == 0;
}


#endif /* AIFFFFFS_H */

/* END OF FILE */
