#!/bin/bash
#
# Encode some random data, then decode it using FLAC to an aiff.
# Finally compare the FLAC decoded aiff to the decode done by aifffffs.
#

FLAC=`which flac 2> /dev/null`

if [ -z "$FLAC" ] ; then
  echo "Could not find 'flac' standalone encoder/decoder.  Skipping test."
  exit 0
fi

fusermount -uz aiff &> /dev/null

for LEVEL in {0..8} ; do

    rm -f rand.aiff rand.raw flac/rand.flac

    mkdir aiff &> /dev/null
    mkdir flac &> /dev/null

    dd if=/dev/urandom of=rand.raw bs=4096 count=40 &> /dev/null &&
    $FLAC -s -$LEVEL --endian=little --sign=signed --channels=2 --bps=16 --sample-rate=44100 rand.raw -o flac/rand.flac &&
    rm rand.raw &&
    $FLAC -s --decode flac/rand.flac -o rand.aiff &&
    ../src/aifffffs -ononempty -r flac aiff &&
    cmp -s aiff/rand.aiff rand.aiff &&
    fusermount -uz aiff &&
    rm rand.aiff ||
    exit 1

done

rm -rf flac/rand.flac

# END OF SCRIPT

