#!/bin/bash
#
# Encode some random data, add tags, then decode it using FLAC to an aiff.
# Compare the FLAC decoded aiff to the decode done by aifffffs using sox to
# get the audio so the tags don't interfere.
#
# This ensures audio samples are unchanged by tag presence.
#

FLAC=`which flac 2> /dev/null`
SOX=`which sox 2> /dev/null`

if [ -z "$FLAC" ] ; then
  echo "Could not find 'flac' standalone encoder/decoder.  Skipping test."
  exit 0
fi

if [ -z "$SOX" ] ; then
  echo "Could not find 'sox' Sound eXchange tool.  Skipping test."
  exit 0
fi

fusermount -uz aiff &> /dev/null

for LEVEL in {0..8} ; do

    rm -f rand.aiff rand.raw flac/rand.flac

    mkdir aiff &> /dev/null
    mkdir flac &> /dev/null

    dd if=/dev/urandom of=rand.raw bs=4096 count=40 &> /dev/null &&
    $FLAC -s -$LEVEL --endian=little --sign=signed --channels=2 --bps=16 --sample-rate=44100 rand.raw -o flac/rand.flac &&
    metaflac --set-tag=ARTIST=test flac/rand.flac
    $FLAC -s --decode flac/rand.flac -o rand.aiff &&
    ../src/aifffffs -ononempty -r flac aiff &&
    cmp -s aiff/rand.aiff rand.aiff ||  # This must fail since the aifffffs version should contain an ID3 tag
    $SOX aiff/rand.aiff --endian little -b 16 out.raw &&
    cmp -s out.raw rand.raw &&          # Extracted audio must still match
    fusermount -uz aiff &&
    rm flac/rand.flac rand.aiff rand.raw out.raw ||
    exit 1

done


# END OF SCRIPT

